@@ -1,10 +1,10 @@
 package Perinci::To::Doc::Role::Section::AddTextLines;
 
-our $DATE = '2017-02-27'; # DATE
-our $VERSION = '0.84'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.85'; # VERSION
 
 use 5.010;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 use Moo::Role;
 
 requires 'doc_lines';
@@ -112,7 +112,7 @@ Perinci::To::Doc::Role::Section::AddTextLines - Provide add_doc_lines() to add t
 
 =head1 VERSION
 
-This document describes version 0.84 of Perinci::To::Doc::Role::Section::AddTextLines (from Perl distribution Perinci-To-Doc), released on 2017-02-27.
+This document describes version 0.85 of Perinci::To::Doc::Role::Section::AddTextLines (from Perl distribution Perinci-To-Doc), released on 2017-07-03.
 
 =head1 DESCRIPTION
 
@@ -166,7 +166,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
